@@ -4,6 +4,7 @@
 #include <QMessageBox>
 #include <QTextStream>
 
+#include "file.h"
 #include "options.h"
 #include "settings.h"
 #include "warningdialog.h"
@@ -23,68 +24,67 @@ ExportHTMLDialog::ExportHTMLDialog(QWidget* parent) : QDialog(parent)
 
     // signals and slots connections
     connect(ui.browseExportDirButton, SIGNAL(pressed()), this, SLOT(browseDirectoryPressed()));
-    connect(ui.browseCSSButton, SIGNAL(pressed()), this, SLOT(browseCSSPressed()));
+    connect(ui.browseCssSrcButton, SIGNAL(pressed()), this, SLOT(browseCssSrcPressed()));
+    connect(ui.browseCssDstButton, SIGNAL(pressed()), this, SLOT(browseCssDstPressed()));
     connect(ui.imageButton, SIGNAL(toggled(bool)), this, SLOT(imageButtonPressed(bool)));
+    connect(ui.TOCButton, SIGNAL(toggled(bool)), this, SLOT(TOCButtonPressed(bool)));
+    connect(ui.numberingButton, SIGNAL(toggled(bool)), this, SLOT(numberingButtonPressed(bool)));
+    connect(ui.taskFlagsButton, SIGNAL(toggled(bool)), this, SLOT(taskFlagsButtonPressed(bool)));
+    connect(ui.userFlagsButton, SIGNAL(toggled(bool)), this, SLOT(userFlagsButtonPressed(bool)));
     connect(ui.textColorButton, SIGNAL(toggled(bool)), this, SLOT(textcolorButtonPressed(bool)));
     connect(ui.lineEditDir, SIGNAL(textChanged(const QString&)), this, SLOT(dirChanged()));
-    connect(ui.lineEditCSS, SIGNAL(textChanged(const QString&)), this, SLOT(cssChanged()));
+    connect(ui.copyCssButton, SIGNAL(pressed()), this, SLOT(copyCssPressed()));
+    connect(ui.lineEditCssSrc, SIGNAL(textChanged(const QString&)), this, SLOT(cssSrcChanged()));
+    connect(ui.lineEditCssDst, SIGNAL(textChanged(const QString&)), this, SLOT(cssDstChanged()));
     connect(ui.saveSettingsInMapButton, SIGNAL(toggled(bool)), this, SLOT(saveSettingsInMapButtonPressed(bool)));
     connect(ui.lineEditPostScript, SIGNAL(textChanged(const QString&)), this, SLOT(postscriptChanged()));
     connect(ui.browsePostExportButton, SIGNAL(pressed()), this, SLOT(browsePostExportButtonPressed()));
 }   
 
-
 void ExportHTMLDialog::readSettings()
 {
-
     dir=settings.localValue (filepath,"/export/html/exportDir",vymBaseDir.currentPath() ).toString();
-    ui.lineEditDir->setText(dir);
+    ui.lineEditDir->setText(dir.absolutePath());
     
-    if ( settings.localValue (filepath,"/export/html/useImage","yes")=="yes")
-	useImage=true;
-    else    
-	useImage=false;
+    useImage=settings.localValue (filepath,"/export/html/useImage","true").toBool();
     ui.imageButton->setChecked(useImage);
 	
-    if ( settings.localValue (filepath,"/export/html/useTextColor","no")=="yes")
-	useTextColor=true;
-    else    
-	useTextColor=false;
+    useTOC=settings.localValue (filepath,"/export/html/useTOC","true").toBool();
+    ui.TOCButton->setChecked(useTOC);
+	
+    useNumbering=settings.localValue (filepath,"/export/html/useNumbering","true").toBool();
+    ui.numberingButton->setChecked(useNumbering);
+	
+    useTaskFlags=settings.localValue (filepath,"/export/html/useTaskFlags","true").toBool();
+    ui.taskFlagsButton->setChecked(useTaskFlags);
+	
+    useUserFlags=settings.localValue (filepath,"/export/html/useUserFlags","true").toBool();
+    ui.userFlagsButton->setChecked(useUserFlags);
+	
+    useTextColor=settings.localValue (filepath,"/export/html/useTextColor","no").toBool();
     ui.textColorButton->setChecked(useTextColor);
     
-/* TODO this was used in old html export, is not yet in new stylesheet
-    if ( settings.readValue ("/export/html/useHeading","no")=="yes")
-	useHeading=true;
-    else    
-	useHeading=false;
+/* FIXME-3 this was used in old html export, is not yet in new stylesheet
+    useHeading=settings.readValue ("/export/html/useHeading","false").toBool();
     checkBox4_2->setChecked(useHeading);
 */	
 
-    if ( settings.localValue (filepath,"/export/html/saveSettingsInMap","no")=="yes")
-	saveSettingsInMap=true;
-    else    
-	saveSettingsInMap=false;
+    saveSettingsInMap=settings.localValue (filepath,"/export/html/saveSettingsInMap","no").toBool();
     ui.saveSettingsInMapButton->setChecked(saveSettingsInMap);
 
-/*
-    if ( settings.value ("/export/html/showOutput","no").toBool())
-	showOutput=true;
-    else    
-	showOutput=false;
-    ui.outputButton->setChecked(showOutput);
-    */
+    //CSS settings
+    css_copy=settings.localValue 
+        (filepath,"/export/html/copy_css",true).toBool();   
+    ui.copyCssButton->setChecked (css_copy);
 
-    // For testing better use local styles
-    const QString defcss(vymBaseDir.path() + "/styles/vym.css");
-    if (options.isOn ("local"))
-    {
-	css=defcss;
-    } else
-    {
-	css=settings.localValue 
-	    (filepath,"/export/html/css",defcss).toString();   
-    }
-    ui.lineEditCSS->setText(css);
+    QString css_org=vymBaseDir.path() + "/styles/vym.css";
+    css_src=settings.localValue 
+        (filepath,"/export/html/css_src",css_org).toString();   
+    css_dst=settings.localValue 
+        (filepath,"/export/html/css_dst",basename(css_org)).toString();   
+    
+    ui.lineEditCssSrc->setText(css_src);
+    ui.lineEditCssDst->setText(css_dst);
     
     postscript=settings.localValue
 	(filepath,"/export/html/postscript","").toString();
@@ -98,14 +98,12 @@ void ExportHTMLDialog::readSettings()
 	"%1\n\n"
 	"Please check, if you really\n"
 	"want to allow this in your system!").arg(postscript));
-	
     }
 }
 
 void ExportHTMLDialog::setDirectory (const QString &d)
 {
-    dir=d;
-    if (dir.right(1)!="/") dir+="/";
+    dir.setPath(d);
 }
 
 void ExportHTMLDialog::dirChanged()
@@ -137,6 +135,30 @@ void ExportHTMLDialog::imageButtonPressed(bool b)
     settingsChanged=true;
 }
 
+void ExportHTMLDialog::TOCButtonPressed(bool b)
+{
+    useTOC=b;
+    settingsChanged=true;
+}
+
+void ExportHTMLDialog::numberingButtonPressed(bool b)
+{
+    useNumbering=b;
+    settingsChanged=true;
+}
+
+void ExportHTMLDialog::taskFlagsButtonPressed(bool b)
+{
+    useTaskFlags=b;
+    settingsChanged=true;
+}
+
+void ExportHTMLDialog::userFlagsButtonPressed(bool b)
+{
+    useUserFlags=b;
+    settingsChanged=true;
+}
+
 void ExportHTMLDialog::textcolorButtonPressed(bool b)
 {
     useTextColor=b; 
@@ -162,18 +184,38 @@ void ExportHTMLDialog::outputButtonPressed(bool b)
     settingsChanged=true;
 }
 
-void ExportHTMLDialog::cssChanged()
+void ExportHTMLDialog::cssSrcChanged()
 {
-    css=ui.lineEditCSS->text();
+    css_src=ui.lineEditCssSrc->text();
     settingsChanged=true;
 }
 
-QString ExportHTMLDialog::getCSSPath()
+void ExportHTMLDialog::cssDstChanged()
 {
-    return css;
+    css_dst=ui.lineEditCssDst->text();
+    settingsChanged=true;
 }
 
-void ExportHTMLDialog::browseCSSPressed()
+QString ExportHTMLDialog::getCssSrc()
+{
+    if (css_copy)
+        return css_src;
+    else
+        return QString();
+}
+
+QString ExportHTMLDialog::getCssDst()
+{
+    return css_dst;
+}
+
+void ExportHTMLDialog::copyCssPressed()
+{
+    css_copy=ui.imageButton->isChecked();
+    settingsChanged=true;
+}
+
+void ExportHTMLDialog::browseCssSrcPressed()
 {
     QFileDialog fd( this);
     fd.setModal (true);
@@ -185,8 +227,27 @@ void ExportHTMLDialog::browseCSSPressed()
     {
 	if (!fd.selectedFiles().isEmpty())
 	{
-	    css=fd.selectedFiles().first();
-	    ui.lineEditCSS->setText (css );
+	    css_src=fd.selectedFiles().first();
+	    ui.lineEditCssSrc->setText (css_src );
+	    settingsChanged=true;
+	}
+    }
+}
+
+void ExportHTMLDialog::browseCssDstPressed()
+{
+    QFileDialog fd( this);
+    fd.setModal (true);
+    fd.setFilter ("Cascading Stylesheet (*.css)");
+    fd.setDirectory (QDir::current());
+    fd.show();
+
+    if ( fd.exec() == QDialog::Accepted )
+    {
+	if (!fd.selectedFiles().isEmpty())
+	{
+	    css_dst=fd.selectedFiles().first();
+	    ui.lineEditCssDst->setText (css_dst );
 	    settingsChanged=true;
 	}
     }
@@ -219,47 +280,27 @@ void ExportHTMLDialog::browsePostExportButtonPressed()
 
 void ExportHTMLDialog::saveSettings ()
 {
-
     // Save options to settings file 
     // (but don't save at destructor, which
     // is called for "cancel", too)
-    settings.setLocalValue (filepath,"/export/html/exportDir",dir);
-    settings.setLocalValue (filepath,"/export/html/postscript",postscript);
-
-    if (useImage)
-	settings.setLocalValue (filepath,"/export/html/useImage","yes");
-    else
-	settings.setLocalValue (filepath,"/export/html/useImage","no");	
-    
-  if (useTextColor)
-	settings.setLocalValue (filepath,"/export/html/useTextColor","yes");
-    else
-	settings.setLocalValue (filepath,"/export/html/useTextColor","no"); 
-    
-   if (showWarnings)
-	settings.setValue ("/export/html/showWarnings","yes");
-    else
-	settings.setValue ("/export/html/showWarnings","no");	
-	    
-    if (showOutput)
-	settings.setValue ("/export/html/showOutput","yes");
-    else
-	settings.setValue ("/export/html/showOutput","no");	
-
-    QString ipath;  
-    ipath=vymBaseDir.path()+"/flags/flag-url-16x16.png";
-    if (!options.isOn ("local"))
-    {
-	settings.setLocalValue 
-	    (filepath,"/export/html/css",css);	
-    }
-
     if (!saveSettingsInMap)
-	settings.clearLocal("/export/html");
+	settings.clearLocal(filepath,"/export/html");
     else    
-	settings.setLocalValue 
-	    (filepath,"/export/html/saveSettingsInMap","yes");
-
+    {
+	settings.setLocalValue (filepath,"/export/html/saveSettingsInMap","yes");
+        settings.setLocalValue (filepath,"/export/html/postscript",postscript);
+        settings.setLocalValue (filepath,"/export/html/useImage",useImage);
+        settings.setLocalValue (filepath,"/export/html/useTOC",useTOC);
+        settings.setLocalValue (filepath,"/export/html/useNumbering",useNumbering);
+        settings.setLocalValue (filepath,"/export/html/useTaskFlags",useTaskFlags);
+        settings.setLocalValue (filepath,"/export/html/useUserFlags",useUserFlags);
+        settings.setLocalValue (filepath,"/export/html/useTextColor",useTextColor);
+        settings.setLocalValue (filepath,"/export/html/css_copy",css_copy);	
+        settings.setLocalValue (filepath,"/export/html/css_src",css_src);	
+        settings.setLocalValue (filepath,"/export/html/css_dst",css_dst);	
+        settings.setValue ("/export/html/showWarnings",showWarnings);
+        settings.setValue ("/export/html/showOutput",showOutput);
+    }
 }
 
 void ExportHTMLDialog::setFilePath(const QString &s)
@@ -272,7 +313,7 @@ void ExportHTMLDialog::setMapName(const QString &s)
     mapname=s;
 }
 
-QString ExportHTMLDialog::getDir()
+QDir ExportHTMLDialog::getDir()
 {
     return dir;
 }
