@@ -37,7 +37,7 @@ ExportBase::~ExportBase()
     removeDir (tmpDir);
 
     // Remember current directory
-    lastExportDir=outDir;
+    lastExportDir=QDir(dirPath);
 }
 
 void ExportBase::init()
@@ -49,22 +49,44 @@ void ExportBase::init()
 	QMessageBox::critical( 0, QObject::tr( "Error" ),
 		       QObject::tr("Couldn't access temporary directory\n"));
     cancelFlag=false;		       
-    outDir=lastExportDir;
+    dirPath=lastExportDir.absolutePath();
 }
 
-void ExportBase::setDirectory (const QDir &d)
+void ExportBase::setDirPath (const QString &s)
 {
-    outDir=d;
+    if (!s.isEmpty()) 
+        dirPath=s;
+    // Otherwise lastExportDir is used, which defaults to current dir
 }
 
-void ExportBase::setFile (const QString &p)
+QString ExportBase::getDirPath()
 {
-    outputFile=p;
+    return dirPath;
 }
 
-QString ExportBase::getFile ()
+void ExportBase::setFilePath (const QString &s)
 {
-    return outputFile;
+    if(!s.isEmpty())
+    {
+        filePath=s;
+        if (!filePath.contains("/"))
+            // Absolute path
+            filePath=lastExportDir.absolutePath() + "/" + filePath;
+    } 
+}
+
+QString ExportBase::getFilePath ()
+{
+    if (!filePath.isEmpty())
+        return filePath;
+    else
+        return dirPath + "/" + model->getMapName() + extension;
+}
+
+QString ExportBase::getMapName ()
+{
+    QString fn=basename(filePath);
+    return fn.left(fn.lastIndexOf("."));
 }
 
 void ExportBase::setModel(VymModel *m)
@@ -87,7 +109,7 @@ bool ExportBase::execDialog(const QString &overwriteWarning)
     QString fn=QFileDialog::getSaveFileName( 
 	NULL,
 	caption,
-	outDir.path(), 
+	dirPath, 
 	filter,
 	NULL,
 	QFileDialog::DontConfirmOverwrite);
@@ -98,8 +120,8 @@ bool ExportBase::execDialog(const QString &overwriteWarning)
 	{
 	    WarningDialog dia;
 	    dia.showCancelButton (true);
-	    dia.setText(QObject::tr("Exporting to %1 will overwrite the existing file:\n%2").arg(overwriteWarning).arg(fn));
 	    dia.setCaption(QObject::tr("Warning: Overwriting file"));
+	    dia.setText(QObject::tr("Exporting to %1 will overwrite the existing file:\n%2").arg(overwriteWarning).arg(fn));
 	    dia.setShowAgainName("/exports/overwrite/"+overwriteWarning);
 	    if (!dia.exec()==QDialog::Accepted)
 	    {
@@ -107,8 +129,8 @@ bool ExportBase::execDialog(const QString &overwriteWarning)
 		return false;
 	    }
 	}
-	outDir.setPath(fn.left(fn.lastIndexOf ("/")) );
-	outputFile=fn;
+	dirPath=fn.left(fn.lastIndexOf ("/"));
+	filePath=fn;
 	if (model) model->setChanged();
 	return true;
     }
@@ -138,24 +160,36 @@ QString ExportBase::getSectionString(TreeItem *start)
 	return r + " ";
 }
 
+QString ExportBase::indent (const int &n, bool useBullet)
+{
+    QString s;
+    for (int i=0; i<n; i++) s += indentPerDepth;
+    if (useBullet && s.length()>=2 && bulletPoints.count()>n) 
+        s.replace(s.length()-2, 1, bulletPoints.at(n) );
+    return s;
+}
+
 ////////////////////////////////////////////////////////////////////////
 ExportAO::ExportAO()
 {
     filter="TXT (*.txt)";
     caption=vymName+ " -" +QObject::tr("Export as ASCII")+" "+QObject::tr("(still experimental)");
-    indentPerDepth=" ";
+    indentPerDepth="   ";
+    bulletPoints.clear();
+    for (int i=0; i<10; i++) 
+        bulletPoints << "-";
 }
 
 void ExportAO::doExport()   
 {
-    QFile file (outputFile);
+    QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) )
     {
-	qWarning()<<"ExportAO::doExport couldn't open "+outputFile;//FIXME-3 missing GUI warning
+	qWarning()<<"ExportAO::doExport couldn't open " + filePath;//FIXME-3 missing GUI warning
 	return;
     }
 
-    settings.setLocalValue (model->getFilePath(),"/export/last/exportDir",outputFile);
+    settings.setLocalValue (model->getFilePath(),"/export/last/exportDir",filePath);// FIXME-2 not needed, use only command
     settings.setLocalValue ( model->getFilePath(), "/export/last/command","exportAO");
     settings.setLocalValue ( model->getFilePath(), "/export/last/description","A&O report");
 
@@ -170,17 +204,19 @@ void ExportAO::doExport()
     BranchItem *cur=NULL;
     BranchItem *prev=NULL;
 
-    QString colString;
-    QColor col;
-
-    cur=model->nextBranch (cur,prev);
+    model->nextBranch (cur,prev);
     while (cur) 
     {
+        QString line;
+        QString colString="";
+        QString noColString;
+        QString statusString ="";
+        QColor col;
+
 	if (cur->getType()==TreeItem::Branch || cur->getType()==TreeItem::MapCenter)
 	{
 	    // Make indentstring
-	    curIndent="";
-	    for (i=0;i<cur->depth()-1;i++) curIndent+= indentPerDepth;
+	    curIndent=indent(cur->depth()-4,true);
 
 	    if (!cur->hasHiddenExportParent() )
 	    {
@@ -191,34 +227,29 @@ void ExportAO::doExport()
 		    colString="[O] ";
 		else if (col==QColor (0,85,0))
 		    colString="[G] ";
-		else	
-		    colString="  - ";
+                else if (cur->depth()==4)
+		    colString="[*] ";
+                else
+		    colString="    ";
+
+                noColString=QString(" ").repeated(colString.length() );
 
 		dashIndent="";	
 		switch (cur->depth())
 		{
-		    case 0:
-			//ts << underline (cur->getHeadingPlain(),QString("="));
-			//ts << "\n";
-			break;
-		    case 1:
-			//ts << "\n";
-			//ts << (underline ( cur->getHeadingPlain(), QString("-") ) );
-			//ts << "\n";
-			break;
-		    case 2: // Main heading
+		    case 0: break;  // Mapcenter (Ignored)
+		    case 1: break;  // Mainbranch "Archive" (Ignored)
+                    case 2: // Title: "Current week number..."
 			ts << "\n";
 			ts << underline ( cur->getHeadingPlain(), QString("=") );
 			ts << "\n";
 			break;
-		    case 3: // Achievement, Bonus, Objective ...
+                    case 3: // Headings: "Achievement", "Bonus", "Objective", ...
 			ts << "\n";
 			ts << underline ( cur->getHeadingPlain(), "-");
 			ts << "\n";
 			break;
-		    default:	// depth 4 are the items we need to know
-			if (cur->depth()>4) ts<<curIndent;
-
+		    default:	// depth 4 and higher are the items we need to know
 			Task *task=cur->getTask();
 			if (task)
 			{
@@ -226,51 +257,60 @@ void ExportAO::doExport()
 			    switch ( task->getStatus() )
 			    {
 				case Task::NotStarted:
-				    ts <<colString+cur->getHeadingPlain()<< " [NOT STARTED] ";
+				    statusString="[NOT STARTED]";
 				    break;
 				case Task::WIP:   
-				    ts <<colString+cur->getHeadingPlain()<< " [WIP] ";
+                                    statusString="[WIP]";
 				    break;
 				case Task::Finished:
-				    ts <<colString+cur->getHeadingPlain()<< " [DONE] ";
+				    statusString="[DONE]";
 				    break;
 			    }
 			} else
 			{
 			    if (cur->hasActiveStandardFlag ("hook-green") )
-				ts <<colString+cur->getHeadingPlain()<< " [DONE] ";
-			    else	if (cur->hasActiveStandardFlag ("wip"))
-				ts <<colString+cur->getHeadingPlain()<< " [WIP] ";
-			    else	if (cur->hasActiveStandardFlag ("cross-red"))
-				ts <<colString+cur->getHeadingPlain()<< " [NOT STARTED] ";
-			    else	
-				ts <<"  - "+cur->getHeadingPlain();
+                                statusString="[DONE]";
+			    else if (cur->hasActiveStandardFlag ("wip"))
+                                statusString="[WIP]";
+			    else if (cur->hasActiveStandardFlag ("cross-red"))
+                                statusString="[NOT STARTED]";
 			}
-			ts << "\n";
+
+                        line += colString;
+                        line += curIndent;
+                        if (cur->depth() >3)
+                            line += cur->getHeadingPlain();
+
+                        // Pad line width before status
+                        i = 80 - line.length() - statusString.length() -1;
+                        for (int j=0; j<i; j++) line += " ";
+                        line += " "  + statusString + "\n";
+
+                        ts << line;
+                        
+                        // If necessary, write URL
+                        if (!cur->getURL().isEmpty())
+                             ts << noColString << indent(cur->depth()-4, false) + cur->getURL() + "\n";
+
+                        // If necessary, write note
+                        if (!cur->getNoteObj().isEmpty())
+                        {
+                            curIndent = noColString + indent(cur->depth()-4,false) + "| ";
+                            s=cur->getNoteASCII( curIndent, 80);
+                            ts << s + "\n";
+                        }
 			break;
 		}
-
-		// If necessary, write URL
-		if (!cur->getURL().isEmpty())
-		    ts << (curIndent + dashIndent + cur->getURL()) +"\n";
-
-		// If necessary, write note
-		if (!cur->getNoteObj().isEmpty())
-		{
-		    curIndent +="  | ";
-		    s=cur->getNoteASCII( curIndent, 80);
-		    ts << s;
-		}
 	    }
 	}
-	cur=model->nextBranch(cur,prev);
+	model->nextBranch(cur,prev);
     }
     file.close();
     QString cmd="exportAO";
-    settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath",outputFile);
+    settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath",filePath);  // FIXME-2 not needed, use only command
     settings.setLocalValue ( model->getFilePath(), "/export/last/command",cmd);
     settings.setLocalValue ( model->getFilePath(), "/export/last/description","A&O report");
-    mainWindow->statusMessage(cmd + ": " + outputFile);
+    mainWindow->statusMessage(cmd + ": " + filePath);
 }
 
 QString ExportAO::underline (const QString &text, const QString &line)
@@ -290,10 +330,10 @@ ExportASCII::ExportASCII()
 
 void ExportASCII::doExport()	
 {
-    QFile file (outputFile);
+    QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) )
     {
-	qWarning ()<<"ExportASCII::doExport couldn't open "+outputFile;
+	qWarning ()<<"ExportASCII::doExport couldn't open "+filePath;
 	return;
     }
     QTextStream ts( &file );	// use LANG decoding here...
@@ -306,7 +346,7 @@ void ExportASCII::doExport()
     BranchItem *cur=NULL;
     BranchItem *prev=NULL;
 
-    cur=model->nextBranch (cur,prev);
+    model->nextBranch (cur,prev);
     while (cur) 
     {
 	if (cur->getType()==TreeItem::Branch || cur->getType()==TreeItem::MapCenter)
@@ -362,14 +402,14 @@ void ExportASCII::doExport()
 		}
 	    }
 	}
-	cur=model->nextBranch(cur,prev);
+	model->nextBranch(cur,prev);
     }
     file.close();
     QString cmd="exportASCII";
-    settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath",outputFile);
+    settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath",filePath);
     settings.setLocalValue ( model->getFilePath(), "/export/last/command",cmd);
     settings.setLocalValue ( model->getFilePath(), "/export/last/description","ASCII");
-    mainWindow->statusMessage(cmd + ": " + outputFile);
+    mainWindow->statusMessage(cmd + ": " + filePath);
 }
 
 QString ExportASCII::underline (const QString &text, const QString &line)
@@ -383,10 +423,10 @@ QString ExportASCII::underline (const QString &text, const QString &line)
 ////////////////////////////////////////////////////////////////////////
 void ExportCSV::doExport()
 {
-    QFile file (outputFile);
+    QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) )
     {
-	qWarning ()<<"ExportBase::exportXML  couldn't open "+outputFile;
+	qWarning ()<<"ExportBase::exportXML  couldn't open "+filePath;
 	return;
     }
     QTextStream ts( &file );	// use LANG decoding here...
@@ -400,7 +440,7 @@ void ExportCSV::doExport()
     int i;
     BranchItem *cur=NULL;
     BranchItem *prev=NULL;
-    cur=model->nextBranch (cur,prev);
+    model->nextBranch (cur,prev);
     while (cur) 
     {
 	if (!cur->hasHiddenExportParent() )
@@ -421,42 +461,12 @@ void ExportCSV::doExport()
 	    ts << curIndent << "\"" << cur->getHeadingPlain()<<"\""<<endl;
 	}
 	
-	cur=model->nextBranch(cur,prev);
+	model->nextBranch(cur,prev);
 	curIndent="";
     }
     file.close();
 }
 
-////////////////////////////////////////////////////////////////////////
-void ExportKDE3Bookmarks::doExport() 
-{
-    WarningDialog dia;
-    dia.showCancelButton (true);
-    dia.setText(QObject::tr("Exporting the %1 bookmarks will overwrite\nyour existing bookmarks file.").arg("KDE"));
-    dia.setCaption(QObject::tr("Warning: Overwriting %1 bookmarks").arg("KDE 3"));
-    dia.setShowAgainName("/exports/overwrite/KDE3Bookmarks");
-    if (dia.exec()==QDialog::Accepted)
-    {
-	model->exportXML(tmpDir.path(),false);
-
-	XSLTProc p;
-	p.setInputFile (tmpDir.path()+"/"+model->getMapName()+".xml");
-	p.setOutputFile (tmpDir.home().path()+"/.kde/share/apps/konqueror/bookmarks.xml");
-	p.setXSLFile (vymBaseDir.path()+"/styles/vym2kdebookmarks.xsl");
-	p.process();
-
-	QString ub=vymBaseDir.path()+"/scripts/update-bookmarks";
-	QProcess *proc= new QProcess ;
-	proc->start( ub);
-	if (!proc->waitForStarted())
-	{
-	    QMessageBox::warning(0, 
-		QObject::tr("Warning"),
-		QObject::tr("Couldn't find script %1\nto notifiy Browsers of changed bookmarks.").arg(ub));
-	}   
-    }
-}
-
 ////////////////////////////////////////////////////////////////////////
 void ExportKDE4Bookmarks::doExport() 
 {
@@ -534,82 +544,121 @@ ExportHTML::ExportHTML(VymModel *m):ExportBase(m)
 
 void ExportHTML::init()
 {
-    singularDelimiter=": ";
-    noSingulars=false;	// Deactivated for the time being...
+    extension=".html";
     frameURLs=true;
-    cssFileName="vym.css";
-    cssOriginalPath="";	// Is set in VymModel, based on default setting in ExportHTMLDialog
-
 }
 
 QString ExportHTML::getBranchText(BranchItem *current)
 {
     if (current)
     {
-	bool vis=false;
-	QRectF hr;
-	LinkableMapObj *lmo=current->getLMO();
-	if (lmo)
-	{
-	    hr=((BranchObj*)lmo)->getBBoxHeading();
-	    vis=lmo->isVisibleObj();
-	}
-	QString col;
-	QString id=model->getSelectString(current);
-	if (dia.useTextColor)
-	    col=QString("style='color:%1'").arg(current->getHeadingColor().name());
-	QString s=QString("<span class='vym-branch%1' %2 id='%3'>")
-	    .arg(current->depth())
-	    .arg(col)
-	    .arg(id);
-	QString url=current->getURL();	
-	QString heading=quotemeta(current->getHeadingPlain());	
-	if (!url.isEmpty())
-	{
-	    s+=QString ("<a href=\"%1\">").arg(url);
-	    s+=QString ("<img src=\"flags/flag-url-16x16.png\">%1</a>").arg(heading);
-	    s+="</a>";
-	    
-	    QRectF fbox=current->getBBoxURLFlag ();
-	    if (vis)	
-		imageMap+=QString("  <area shape='rect' coords='%1,%2,%3,%4' href='%5'>\n")
-		    .arg(fbox.left()-offset.x())
-		    .arg(fbox.top()-offset.y())
-		    .arg(fbox.right()-offset.x())
-		    .arg(fbox.bottom()-offset.y())
-		    .arg(url);
-	} else	
-	    s+=quotemeta(current->getHeadingPlain());	
-	s+="</span>";
+        bool vis=false;
+        QRectF hr;
+        LinkableMapObj *lmo=current->getLMO();
+        if (lmo)
+        {
+            hr=((BranchObj*)lmo)->getBBoxHeading();
+            vis=lmo->isVisibleObj();
+        }
+        QString col;
+        QString id=model->getSelectString(current);
+        if (dia.useTextColor)
+            col=QString("style='color:%1'").arg(current->getHeadingColor().name());
+        QString s=QString("<span class='vym-branch-%1' %2 id='%3'>")
+            .arg(current->depth())
+            .arg(col)
+            .arg(id);
+        QString url=current->getURL();	
+        QString heading=quotemeta(current->getHeadingPlain());	
 
-	if (vis && dia.useImage)
-	    imageMap+=QString("  <area shape='rect' coords='%1,%2,%3,%4' href='#%5'>\n")
-		.arg(hr.left()-offset.x())
-		.arg(hr.top()-offset.y())
-		.arg(hr.right()-offset.x())
-		.arg(hr.bottom()-offset.y())
-		.arg(id);
+        // Task flags
+        QString taskFlags;
+        if (dia.useTaskFlags)
+        {
+            Task *task=current->getTask();
+            if (task)
+                taskFlags+=QString("<img src=\"flags/flag-%1.png\">").arg(task->getIconString());
+        }
 
-	// Include note
-	if (!current->getNoteObj().isEmpty())
-	{
-	    QString n;
-	    if (current->getNoteObj().isRichText())
-	    {
-		n=current->getNote();
-		QRegExp re("<p.*>");
-		re.setMinimal (true);
-		n.replace(re,"<p class=\"vym-note-paragraph\">");
-	    }
-	    else
-	    {
-		n=current->getNoteASCII().replace ("<","&lt;").replace (">","&gt;");
-		n.replace("\n","<br/>");
-	    }
-	    s+="\n<table class=\"vym-note\"><tr><td>\n"+n+"\n</td></tr></table>\n";
-	}   
+        // User flags
+        QString userFlags;
+        if (dia.useUserFlags)
+        {
+            foreach (QString flag, current->activeStandardFlagNames())
+                userFlags+=QString("<img src=\"flags/flag-%1.png\">").arg(flag);
+        }
 
-	return s;
+        // URL
+        if (!url.isEmpty())
+        {
+            s+=QString ("<a href=\"%1\"><img src=\"flags/flag-url-16x16.png\">%2</a>")
+                .arg(url)
+                .arg(taskFlags + heading + userFlags);
+
+            QRectF fbox=current->getBBoxURLFlag ();
+            if (vis)	
+                imageMap+=QString("  <area shape='rect' coords='%1,%2,%3,%4' href='%5'>\n")
+                .arg(fbox.left()-offset.x())
+                .arg(fbox.top()-offset.y())
+                .arg(fbox.right()-offset.x())
+                .arg(fbox.bottom()-offset.y())
+                .arg(url);
+        } else
+            s+=taskFlags + heading + userFlags;
+
+        s+="</span>";
+
+        // Create imagemap
+        if (vis && dia.useImage)
+            imageMap+=QString("  <area shape='rect' coords='%1,%2,%3,%4' href='#%5'>\n")
+                .arg(hr.left()-offset.x())
+                .arg(hr.top()-offset.y())
+                .arg(hr.right()-offset.x())
+                .arg(hr.bottom()-offset.y())
+                .arg(id);
+
+        // Include note
+        if (!current->getNoteObj().isEmpty())
+        {
+            QString n;
+            if (current->getNoteObj().isRichText())
+            {
+                n=current->getNote();
+                QRegExp re("<p.*>");
+                re.setMinimal (true);
+                if (current->getNoteObj().getFontHint() == "fixed")
+                    n.replace(re,"<p class=\"vym-fixed-note-paragraph\">");
+                else
+                    n.replace(re,"<p class=\"vym-note-paragraph\">");
+
+                re.setPattern("</?html>");
+                n.replace(re,"");
+
+                re.setPattern("</?head.*>");
+                n.replace(re,"");
+
+                re.setPattern("</?body.*>");
+                n.replace(re,"");
+
+                re.setPattern("</?meta.*>");
+                n.replace(re,"");
+
+                re.setPattern("<style.*>.*</style>");
+                n.replace(re,"");
+
+                //re.setPattern("<!DOCTYPE.*>");
+                //n.replace(re,"");
+            }
+            else
+            {
+                n=current->getNoteASCII().replace ("<","&lt;").replace (">","&gt;");
+                n.replace("\n","<br/>");
+                if (current->getNoteObj().getFontHint()=="fixed")
+                n="<pre>"+n+"</pre>";
+            }
+            s+="\n<table class=\"vym-note\"><tr><td class=\"vym-note-flag\">\n<td>\n"+n+"\n</td></tr></table>\n";
+        }   
+        return s;
     } 
     return QString();
 }
@@ -619,71 +668,125 @@ QString ExportHTML::buildList (BranchItem *current)
     QString r;
 
     uint i=0;
+    uint visChilds=0;
+
     BranchItem *bi=current->getFirstBranch();
 
-    // Only add itemized list, if we have more than one subitem.
-    // For only one subitem, just add a separator to keep page more compact
-    bool noSingularsHere=false;
-    if (current->branchCount()<2 && noSingulars) noSingularsHere=true;
+    QString ind="\n" + indent(current->depth() + 1, false);
 
-    if (bi)
+    QString sectionBegin;
+    QString sectionEnd;
+    QString itemBegin;
+    QString itemEnd;
+
+    switch (current->depth() + 1)
     {
-	if (!noSingularsHere)
-	    r+="<ul>\n";
-	else
-	    r+=singularDelimiter;
-
+        case 0: 
+            sectionBegin="";
+            sectionEnd="";
+            itemBegin="<h1>";
+            itemEnd="</h1>";
+            break;
+        case 1: 
+            sectionBegin="";
+            sectionEnd="";
+            itemBegin="<h2>";
+            itemEnd="</h2>";
+            break;
+        default:
+            sectionBegin="<ul " + QString("class=\"vym-list-ul-%1\"").arg(current->depth() + 1)  +">";
+            sectionEnd="</ul>";
+            itemBegin="  <li>";
+            itemEnd="  </li>";
+            break;
+    }
+    
+    if (bi && !bi->hasHiddenExportParent() && !bi->isHidden() )	
+    {
+        r+=ind + sectionBegin; 
 	while (bi)
 	{
-	    if (!bi->hasHiddenExportParent() )	
+	    if (!bi->hasHiddenExportParent() && !bi->isHidden()) 
 	    {
-		if (!noSingularsHere) r+="<li>";
+                visChilds++;
+		r+=ind + itemBegin;
 		r+=getBranchText (bi);
-		if (!bi->getURL().isEmpty() && frameURLs && noSingularsHere)
-		    // Add frame, if we have subitems to an URL
-		    r+="<table border=1><tr><td>"+buildList (bi)+"</td></tr></table>";	// recursivly add deeper branches
-		else
-		    r+=buildList (bi);	// recursivly add deeper branches
-		if (!noSingularsHere) r+="</li>";
-		r+="\n";
+
+                if (itemBegin.startsWith("<h") )
+                    r+=itemEnd + buildList (bi);
+                else
+                    r+=buildList (bi) + itemEnd;	
 	    }
 	    i++;
 	    bi=current->getBranchNum(i);
 	}
-
-	if (!noSingularsHere) r+="</ul>\n";
+        r+=ind + sectionEnd;
     }
+
     return r;
 }
 
-void ExportHTML::setCSSPath(const QString &p)
+QString ExportHTML::createTOC()
 {
-    cssOriginalPath=p;
+    QString toc;
+    QString number;
+    toc += "<table class=\"vym-toc\">\n";
+    toc += "<tr><td class=\"vym-toc-title\">\n"; 
+    toc += QObject::tr("Contents:","Used in HTML export");
+    toc += "\n";
+    toc += "</td></tr>\n"; 
+    toc += "<tr><td>\n"; 
+    BranchItem *cur=NULL;
+    BranchItem *prev=NULL;
+    model->nextBranch(cur,prev);
+    while (cur) 
+    {
+	if (!cur->hasHiddenExportParent() && !cur->hasScrolledParent() )
+	{
+            if (dia.useNumbering) number=getSectionString(cur);
+            toc +=QString("<div class=\"vym-toc-branch-%1\">").arg(cur->depth());
+	    toc +=QString("<a href=\"#%1\"> %2 %3</a></br>\n")
+                .arg(model->getSelectString(cur))
+                .arg(number)
+                .arg(cur->getHeadingPlain());
+            toc +="</div>";
+	}
+	model->nextBranch(cur,prev);
+    }
+    toc += "</td></tr>\n"; 
+    toc += "</table>\n"; 
+    return toc;
 }
 
 void ExportHTML::doExport(bool useDialog) 
 {
-    // Execute dialog
-    dia.setFilePath (model->getFilePath());
+    // Setup dialog and read settings
     dia.setMapName (model->getMapName());
     dia.readSettings();
+
+    if (!dirPath.isEmpty()) 
+        dia.setDirectory(dirPath);
+
+    if (!filePath.isEmpty())
+        dia.setFilePath (filePath);
+    else
+        dia.setFilePath (model->getFilePath());
+
     if (useDialog)
     {
 	if (dia.exec()!=QDialog::Accepted) return;
 	model->setChanged();
     }
 
-    // Check if destination is not empty
-    QDir d=dia.getDir();
     // Check, if warnings should be used before overwriting
     // the output directory
-    if (d.exists() && d.count()>0)
+    if (dia.getDir().exists() && dia.getDir().count()>0)
     {
 	WarningDialog warn;
 	warn.showCancelButton (true);
 	warn.setText(QString(
 	    "The directory %1 is not empty.\n"
-	    "Do you risk to overwrite some of its contents?").arg(d.path() ));
+	    "Do you risk to overwrite some of its contents?").arg(dia.getDir().absolutePath() ));
 	warn.setCaption("Warning: Directory not empty");
 	warn.setShowAgainName("mainwindow/export-XML-overwrite-dir");
 
@@ -694,101 +797,99 @@ void ExportHTML::doExport(bool useDialog)
 	}
     }
 
-    setFile (d.path()+"/"+model->getMapName()+".html");
-    setCSSPath( dia.getCSSPath() ); 
-
-    // Copy CSS file
-    QString css;
-
-    QString css_src (cssOriginalPath);
-    QString css_dst (d.path()+"/"+cssFileName);
-    if (!loadStringFromDisk (css_src,css))
-	QMessageBox::warning( 0, 
-	    QObject::tr( "Warning","ExportHTML" ),
-	    QObject::tr("Trying to load stylesheet:")+"\n\n"+
-	    QObject::tr("Could not open %1","ExportHTML").arg(cssOriginalPath));
-    else
+    dirPath=dia.getDir().absolutePath(); 
+    filePath=getFilePath();
+    
+    // Copy CSS file 
+    if (dia.css_copy)
     {
-	if (!saveStringToDisk (css_dst,css))
-	    QMessageBox::warning( 0, 
-		QObject::tr( "Warning" ), 
-		QObject::tr("Trying to save stylesheet:")+"\n\n"+
-		QObject::tr("Could not open %1").arg(css_dst));
+        cssSrc=dia.getCssSrc();
+        cssDst=dia.getDir().absolutePath() + "/" + basename(dia.getCssDst());
+        if (cssSrc.isEmpty() )
+        {
+            QMessageBox::critical( 0,
+            QObject:: tr( "Critical" ),
+            QObject::tr("Could not find stylesheet %1").arg(cssSrc));
+            return;
+        }
+        QFile src(cssSrc);
+        QFile dst(cssDst);
+        if (dst.exists() ) dst.remove();
+
+        if (!src.copy(cssDst))
+        {
+            QMessageBox::critical (0,
+                    QObject::tr( "Error","ExportHTML" ),
+                    QObject::tr("Could not copy\n%1 to\n%2","ExportHTML").arg(cssSrc).arg(cssDst));
+            return;
+        }
     }
 
-    // Provide a smaller URL-icon to improve Layout 
-    QPixmap pm;
-    QString urlName="flag-url-16x16.png";
-    QString ipath=flagsPath+urlName;
-
-    if (!pm.load(ipath,"PNG") )
-	QMessageBox::warning( 0, 
-	QObject::tr( "Warning" ),
-	QObject::tr("Trying to load small icon for URLs:")+"\n\n"+
-	QObject::tr("Could not open %1").arg(ipath));
-    else
+    // Copy flags
+    QDir flagsDst(dia.getDir().absolutePath() + "/flags");
+    if (!flagsDst.exists())
     {
-	QString flagsPathExport=d.path()+"/flags";
-	if (!d.exists(d.path()+"/flags"))
-	{
-	    if (!d.mkdir  ("flags"))
-		QMessageBox::warning( 0,
-		QObject:: tr( "Warning" ),
-		QObject::tr("Trying to create directory for flags:")+"\n\n"+
-		QObject::tr("Could not create %1").arg(flagsPathExport));
-	}   
-	if(!pm.save (flagsPathExport+"/"+urlName,"PNG"))
-	    QMessageBox::warning( 0,
-	    QObject::tr( "Warning" ),
-	    QObject::tr("Trying to save small icon for URLs:")+"\n\n"+
-	    QObject::tr("Could not write %1").arg(flagsPathExport+"/"+urlName));
-    }	
+        if (!dia.getDir().mkdir("flags"))
+        {
+            QMessageBox::critical( 0,
+            QObject:: tr( "Critical" ),
+            QObject::tr("Trying to create directory for flags:")+"\n\n"+
+            QObject::tr("Could not create %1").arg(flagsDst.absolutePath()));
+            return;
+        }
+    }   
+
+    QDir flagsSrc(flagsPath);
+    if (!copyDir(flagsSrc,flagsDst,true))
+    {
+        QMessageBox::critical( 0,
+                QObject:: tr( "Critical" ),
+                QObject::tr("Could not copy %1 to %2").arg(flagsSrc.absolutePath()).arg(flagsDst.absolutePath()));
+        return;
+    }
+
     // Open file for writing
-    QFile file (outputFile);
+    QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) ) 
     {
 	QMessageBox::critical (0,
 	    QObject::tr("Critical Export Error"),
 	    QObject::tr("Trying to save HTML file:")+"\n\n"+
-	    QObject::tr("Could not write %1").arg(outputFile));
+	    QObject::tr("Could not write %1").arg(filePath));
 	mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
 	return;
     }
     QTextStream ts( &file );	// use LANG decoding here...
     //FIXME-4 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
 
-    // Include image (be careful: this resets Export mode, so call before exporting branches)
-    if (dia.useImage)
-    {
-	ts<<"<center><img src=\""<<model->getMapName()<<".png\" usemap='#imagemap'></center>\n";
-	offset=model->exportImage (d.path()+"/"+model->getMapName()+".png",false,"PNG");
-    }
-
     // Hide stuff during export
     model->setExportMode (true);
 
     // Write header
     ts<<"<html>";
-    ts<<"<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"> ";
-    ts<<"<meta name=\"generator=\" content=\" vym - view your mind - " + vymHome + "\">"; 
-    ts<<"<meta name=\"author\" content=\"" + model->getAuthor() + "\"> ";
-    ts<<"<meta name=\"description\" content=\"" + model->getComment() + "\"> ";
-    ts<<"<title>"+model->getMapName()<<"</title><body>";
-    ts<<" <link rel='stylesheet' id='css.stylesheet' href='"<<cssFileName<<"' />\n";
+    ts<<"\n<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"> ";
+    ts<<"\n<meta name=\"generator=\" content=\" vym - view your mind - " + vymHome + "\">"; 
+    ts<<"\n<meta name=\"author\" content=\"" + quotemeta(model->getAuthor()) + "\"> ";
+    ts<<"\n<meta name=\"description\" content=\"" + quotemeta(model->getComment()) + "\"> ";
+    ts<<"\n<link rel='stylesheet' id='css.stylesheet' href='"<<basename(cssDst)<<"' />\n";
+    QString title=model->getTitle();
+    if (title.isEmpty()) title=model->getMapName();
+    ts<<"\n<head><title>" + quotemeta(title) + "</title></head>";
+    ts<<"\n<body>\n";
+
+    // Include image 
+    // (be careful: this resets Export mode, so call before exporting branches)
+    if (dia.useImage)
+    {
+	ts<<"<center><img src=\""<<getMapName()<<".png\" usemap='#imagemap'></center>\n";
+	offset=model->exportImage (dirPath+"/"+getMapName()+".png",false,"PNG");
+    }
+
+    // Include table of contents
+    if (dia.useTOC) ts << createTOC();
 
     // Main loop over all mapcenters
-    QString s;
-    TreeItem *rootItem=model->getRootItem();
-    BranchItem *bi;
-    for (int i=0; i<rootItem->branchCount(); i++)
-    {
-	bi=rootItem->getBranchNum(i);
-	if (!bi->hasHiddenExportParent())
-	{
-	    ts<<getBranchText (bi);
-	    ts<<buildList (bi);
-	}
-    }	
+    ts << buildList(model->getRootItem()) << "\n";
 
     // Imagemap
     ts<<"<map name='imagemap'>\n"+imageMap+"</map>\n";
@@ -797,7 +898,7 @@ void ExportHTML::doExport(bool useDialog)
     ts<<"<hr/>\n";
     ts<<"<table class=\"vym-footer\">   \n\
       <tr> \n\
-        <td class=\"vym-footerL\">"+model->getFileName()+"</td> \n\
+        <td class=\"vym-footerL\">"+filePath+"</td> \n\
         <td class=\"vym-footerC\">"+model->getDate()+"</td> \n\
         <td class=\"vym-footerR\"> <a href='" + vymHome + "'>vym "+vymVersion+"</a></td> \n\
       </tr> \n \
@@ -808,14 +909,17 @@ void ExportHTML::doExport(bool useDialog)
     if (!dia.postscript.isEmpty()) 
     {
 	Process p;
-	p.runScript (dia.postscript,d.path()+"/"+model->getMapName()+".html");
+	p.runScript (dia.postscript,dirPath + "/" + filePath);
     }
 
     QString cmd="exportHTML";
-    settings.setLocalValue (model->getFilePath(),"/export/last/exportPath",d.path());
-    settings.setLocalValue ( model->getFilePath(), "/export/last/command","exportHTML");
+    settings.setLocalValue ( model->getFilePath(), "/export/last/command",QString("exportHTML(\"%1\",\"%2\")")
+            .arg(dirPath)
+            .arg(filePath)
+            );
     settings.setLocalValue ( model->getFilePath(), "/export/last/description","HTML");
-    mainWindow->statusMessage(cmd + ": " + outputFile);
+    settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath",filePath); 
+    mainWindow->statusMessage(cmd + ": " + filePath);
 
     dia.saveSettings();
     model->setExportMode (false);
@@ -828,7 +932,7 @@ void ExportTaskjuggler::doExport()
 
     XSLTProc p;
     p.setInputFile (tmpDir.path()+"/"+model->getMapName()+".xml");
-    p.setOutputFile (outputFile);
+    p.setOutputFile (filePath);
     p.setXSLFile (vymBaseDir.path()+"/styles/vym2taskjuggler.xsl");
     p.process();
 }
@@ -839,10 +943,10 @@ void ExportOrgMode::doExport()
     // Exports a map to an org-mode file.  
     // This file needs to be read 
     // by EMACS into an org mode buffer
-    QFile file (outputFile);
+    QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) ) 
     {
-	QMessageBox::critical (0,QObject::tr("Critical Export Error"),QObject::tr("Could not write %1").arg(outputFile));
+	QMessageBox::critical (0,QObject::tr("Critical Export Error"),QObject::tr("Could not write %1").arg(filePath));
 	mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
 	return;
     }
@@ -869,7 +973,7 @@ void ExportOrgMode::doExport()
 		ts << ("\n");
 	    }
 	}
-	cur=model->nextBranch(cur,prev);
+	model->nextBranch(cur,prev);
     }
     file.close();
 }
@@ -900,7 +1004,7 @@ QString ExportLaTeX::escapeLaTeX(const QString &s)
 
     foreach (QString p,esc.keys() )
     {
-	qDebug()<<"Replacing "<<p<<" with "<<esc[p];
+	qDebug()<<"Replacing "<<p<<" with "<<esc[p];    // FIXME-2
 	rx.setPattern (p);
 	r.replace (rx, esc[p] );
     }	
@@ -914,12 +1018,12 @@ void ExportLaTeX::doExport()
     // or inported into a LaTex document
     // it will not add a preamble, or anything 
     // that makes a full LaTex document.
-  QFile file (outputFile);
+  QFile file (filePath);
   if ( !file.open( QIODevice::WriteOnly ) ) {
     QMessageBox::critical (
 	0,
 	QObject::tr("Critical Export Error"),
-	QObject::tr("Could not write %1").arg(outputFile));
+	QObject::tr("Could not write %1").arg(filePath));
 	mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
     return;
   }
@@ -967,15 +1071,15 @@ void ExportLaTeX::doExport()
 	  ts << endl;
 	}
     }
-    cur=model->nextBranch(cur,prev);
+    model->nextBranch(cur,prev);
    }
     
     file.close();
     QString cmd="exportLaTeX";
-    settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath",outputFile);
+    settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath",filePath);
     settings.setLocalValue ( model->getFilePath(), "/export/last/command",cmd);
     settings.setLocalValue ( model->getFilePath(), "/export/last/description","LaTeX");
-    mainWindow->statusMessage(cmd + ": " + outputFile);
+    mainWindow->statusMessage(cmd + ": " + filePath);
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -1109,14 +1213,14 @@ void ExportOO::exportPresentation()
     f.close();
 
     // zip tmpdir to destination
-    zipDir (tmpDir,outputFile);	
+    zipDir (tmpDir,filePath);	
 
     QString cmd="exportImpres";
-    settings.setLocalValue (model->getFilePath(),"/export/last/exportPath",outputFile);
+    settings.setLocalValue (model->getFilePath(),"/export/last/exportPath",filePath);
     settings.setLocalValue ( model->getFilePath(), "/export/last/command","exportImpress");
     settings.setLocalValue ( model->getFilePath(), "/export/last/configFile",configFile);
     settings.setLocalValue ( model->getFilePath(), "/export/last/description","OpenOffice.org Impress");
-    mainWindow->statusMessage(cmd + ": " + outputFile);
+    mainWindow->statusMessage(cmd + ": " + filePath);
 }
 
 bool ExportOO::setConfigFile (const QString &cf)
