@@ -21,9 +21,11 @@ public:
     ExportBase(VymModel *m);
     virtual ~ExportBase();
     virtual void init();
-    virtual void setDirectory (const QDir&);
-    virtual void setFile (const QString &);
-    virtual QString getFile ();
+    virtual void setDirPath (const QString&);
+    virtual QString getDirPath();
+    virtual void setFilePath (const QString&);
+    virtual QString getFilePath ();
+    virtual QString getMapName ();
     virtual void setModel (VymModel *m);
     virtual void setWindowTitle (const QString &);
     virtual void addFilter (const QString &);
@@ -33,10 +35,14 @@ protected:
     VymModel *model;
     virtual QString getSectionString (TreeItem*);
 
+    QString indent (const int &n, bool useBullet);
     QDir tmpDir;
-    QDir outDir;
-    QString outputFile;
+    QString dirPath;    // Path to dir  e.g. /tmp/vym-export/
+    QString filePath;   // Path to file e.g. /tmp/vym-export/export.html
+    QString extension;  // Extension, e.g. .html
     QString indentPerDepth;
+    int indentPerDepth2;
+    QStringList bulletPoints;
     QString caption;
     QString filter;
     bool cancelFlag;
@@ -72,13 +78,6 @@ class ExportXMLBase:public ExportBase
 {
 };
 
-///////////////////////////////////////////////////////////////////////
-class ExportKDE3Bookmarks:public ExportXMLBase
-{
-public:
-    virtual void doExport();
-};  
-
 ///////////////////////////////////////////////////////////////////////
 class ExportKDE4Bookmarks:public ExportXMLBase
 {
@@ -101,18 +100,16 @@ public:
     ExportHTML();
     ExportHTML(VymModel *m);
     virtual void init();
-    virtual void setCSSPath(const QString &path);
+    virtual QString createTOC();
     virtual void doExport(bool useDialog=true);
 private:
     QString getBranchText(BranchItem *);
     QString buildList (BranchItem *);
     QString imageMap;
-    QString cssFileName;
-    QString cssOriginalPath;
+    QString cssSrc;
+    QString cssDst;
 
     bool frameURLs;
-    bool noSingulars;
-    QString singularDelimiter;
 
     QPointF offset;
 
