@@ -55,6 +55,12 @@ QString convertToRel (const QString &src, const QString &dst)
     return d;
 }
 
+QString basename(const QString &path)
+{
+    return path.section ('/', -1);
+
+}
+
 extern QString vymName;
 bool reallyWriteDirectory(const QString &dir)
 {
@@ -167,9 +173,39 @@ void removeDir(QDir d)
 	qWarning ()<<"removeDir("+d.path()+") failed!";
 }	
 
-void copyDir (QDir src, QDir dst)   //FIXME-5 don't use system call
+bool copyDir (QDir src, QDir dst, const bool &override)   
 {
-    system (QString ("cp -r "+src.path()+"/* "+dst.path()).toUtf8() );
+    QStringList dirs  = src.entryList(QDir::AllDirs | QDir::Hidden | QDir::NoDotAndDotDot);
+    QStringList files = src.entryList(QDir::Files );
+
+    // Check if dst is a subdir of src, which would cause endless recursion...
+    if (dst.absolutePath().contains(src.absolutePath())) return false;
+    
+    // Traverse directories
+    QList<QString>::iterator d,f;
+    for (d = dirs.begin(); d != dirs.end(); ++d) 
+    {
+        if (!QFileInfo(src.path() + "/" + (*d)).isDir()) continue;
+
+        QDir cdir(dst.path() + "/" + (*d));
+        cdir.mkpath(cdir.path());
+
+        if (!copyDir (QDir(src.path() + "/" + (*d)), QDir(dst.path() + "/" + (*d)), override)) 
+            return false;
+    }
+
+    // Traverse files
+    for (f = files.begin(); f != files.end(); ++f) 
+    {
+        QFile cfile(src.path() + "/" + (*f));
+        QFile destFile(dst.path()+ "/" + src.relativeFilePath(cfile.fileName()));
+        if (destFile.exists() && override) 
+            destFile.remove();
+
+        if (!cfile.copy(dst.path() + "/" + src.relativeFilePath(cfile.fileName()))) 
+            return false;
+    }
+    return true;
 }
 
 void makeSubDirs (const QString &s)
@@ -384,7 +420,7 @@ FileType getMapType (const QString &fn)
     if (i>=0)
     {
 	QString postfix=fn.mid(i+1);
-	if (postfix=="vym" || postfix=="vyp") return VymMap;
+	if (postfix=="vym" || postfix=="vyp" || postfix=="xml") return VymMap;
 	if (postfix=="mm") return FreemindMap;	
     }
     return UnknownMap;
