@@ -15,6 +15,7 @@ enum FileType {VymMap, FreemindMap,UnknownMap};
 /////////////////////////////////////////////////////////////////////////////
 QString maskPath (QString );
 QString convertToRel (const QString &,const QString &);
+QString basename (const QString&);
 
 QString browseDirectory (QWidget *parent=NULL, const QString &caption="");
 bool reallyWriteDirectory(const QString &dir);
@@ -23,7 +24,7 @@ QString makeTmpDir (bool &ok, QString prefix);
 bool isInTmpDir (QString fn);
 QString makeUniqueDir (bool &ok, QString);
 void removeDir(QDir);
-void copyDir (QDir src,QDir dst);
+bool copyDir (QDir src,QDir dst, const bool &override=false);
 void makeSubDirs (const QString &);
 File::ErrorCode zipDir (const QDir &,const QString&);
 File::ErrorCode unzipDir (const QDir &,const QString&);
