@@ -44,20 +44,6 @@ QString ImportBase::getTransformedFile()
     return transformedFile;
 }
 
-/////////////////////////////////////////////////
-bool ImportKDE3Bookmarks::transform()
-{
-    transformedFile=tmpDir.path()+"/bookmarks.xml";
-
-    XSLTProc p;
-    p.setInputFile (tmpDir.home().path()+"/.kde/share/apps/konqueror/bookmarks.xml");
-    p.setOutputFile (transformedFile);
-    p.setXSLFile (vymBaseDir.path()+"/styles/kdebookmarks2vym.xsl");
-    p.process();
-
-    return true;
-}
-
 /////////////////////////////////////////////////
 bool ImportKDE4Bookmarks::transform() 
 {
