@@ -10,6 +10,7 @@ using namespace std;
 #include "flagrow.h"
 #include "flagrowobj.h"
 #include "headingeditor.h"
+#include "macros.h"
 #include "mainwindow.h"
 #include "noteeditor.h"
 #include "options.h"
@@ -48,7 +49,7 @@ Main *mainWindow;		// used in BranchObj::select()
 FindWidget *findWidget;
 FindResultWidget *findResultWidget;
 
-QDBusConnection dbusConnection= QDBusConnection::sessionBus();
+Macros macros;
 
 uint itemLastID=0;		// Unique ID for all items in all models
 
@@ -200,7 +201,7 @@ int main(int argc, char* argv[])
     // Register for DBUS
     if (debug) cout << "PID="<<getpid()<<endl;
     QString pidString=QString ("%1").arg(getpid());
-    if (!dbusConnection.registerService ("org.insilmaril.vym-"+pidString))
+    if (!QDBusConnection::sessionBus().registerService ("org.insilmaril.vym-"+pidString))
     {
        fprintf(stderr, "%s\n",
 	    qPrintable(QDBusConnection::sessionBus().lastError().message()));        
