@@ -5,7 +5,7 @@
 #include <QtDBus>
 
 
-#include "branchpropwindow.h"
+#include "branchpropeditor.h"
 #include "extrainfodialog.h"
 #include "flag.h"
 #include "file.h"
@@ -104,7 +104,6 @@ public slots:
 private slots:	
     void fileSaveAs(const SaveMode &);
     void fileSaveAs();
-    void fileImportKDE3Bookmarks();
     void fileImportKDE4Bookmarks();
     void fileImportFirefoxBookmarks();
     void fileImportFreemind();
@@ -120,11 +119,11 @@ private slots:
     void fileExportCSV();
     void fileExportOrgMode();
     void fileExportLaTeX();
-    void fileExportKDE3Bookmarks();
     void fileExportKDE4Bookmarks();
     void fileExportTaskjuggler();
     void fileExportImpress();
     void fileExportLast();
+    bool closeTab(int i);
     bool fileCloseMap();
     void filePrint();
     bool fileExitVYM();
@@ -141,6 +140,7 @@ private slots:
 public slots:    
     void updateQueries (VymModel*);
 private:
+    bool openURL(const QString &url);
     void openTabs(QStringList);
 public slots:
     void editOpenURL();
@@ -324,7 +324,7 @@ private:
     QDockWidget *noteEditorDW;
     QDockWidget *scriptEditorDW;
 
-    BranchPropertyWindow *branchPropertyWindow;
+    BranchPropertyEditor *branchPropertyEditor;
 
     QList <QAction*> actionListMap;
     QList <QAction*> actionListBranches;
@@ -477,7 +477,7 @@ private:
     QAction *actionViewToggleSlideEditor;
     QAction *actionViewToggleScriptEditor;
     QAction *actionViewToggleHistoryWindow;
-    QAction *actionViewTogglePropertyWindow;
+    QAction *actionViewTogglePropertyEditor;
     QAction *actionViewToggleAntiAlias;
     QAction *actionViewToggleSmoothPixmapTransform;
     QAction* actionViewCenter;
