@@ -563,11 +563,12 @@ void MapEditor::print()
 
 QRectF MapEditor::getTotalBBox()    //FIXME-2 frames missing, esp. cloud
 {				    //FIXME-2 xlinks also missing in getTotalBBox
+    //FIXME-1 qDebug()<<"ME::getTotalBBox";
     QRectF rt;
     BranchObj *bo;
     BranchItem *cur=NULL;
     BranchItem *prev=NULL;
-    model->nextBranch(cur,prev);
+    model->nextBranch(cur,prev,true);
     while (cur) 
     {
 	if (!cur->hasHiddenExportParent())
@@ -576,6 +577,8 @@ QRectF MapEditor::getTotalBBox()    //FIXME-2 frames missing, esp. cloud
 	    bo=(BranchObj*)(cur->getLMO());
 	    if (bo && bo->isVisibleObj())
 	    {
+                //FIXME-8 
+                if (debug) qDebug()<<"ME::getTotalBBox bo="<<cur->getHeading();
 		bo->calcBBoxSizeWithChildren();
 		QRectF r1=bo->getBBox();
 
@@ -591,10 +594,10 @@ QRectF MapEditor::getTotalBBox()    //FIXME-2 frames missing, esp. cloud
 		if (fio) rt=addBBox (fio->getBBox(),rt);
 	    }
 	}
-	model->nextBranch(cur,prev);
+	model->nextBranch(cur,prev,true);
     }
 
-    // XLinks	 //FIXME missing
+    // get bboxes of XLinks	 //FIXME-2 missing
 
     // Update scene according to new bbox
     if (!sceneRect().contains (rt) )
@@ -602,7 +605,6 @@ QRectF MapEditor::getTotalBBox()    //FIXME-2 frames missing, esp. cloud
     return rt;	
 }
 
-
 QImage MapEditor::getImage( QPointF &offset) 
 {
     QRectF mapRect=getTotalBBox();
@@ -770,7 +772,15 @@ TreeItem* MapEditor::findMapItem (QPointF p,TreeItem *exclude)
 	{
 	    XLinkObj *xlo=link->getXLinkObj();
 	    if (xlo && xlo->isInClickBox (p)) 
-		    return link->getBeginLinkItem();
+            {
+                // Found XLink, now return the nearest XLinkItem of p
+                qreal d0=Geometry::distance(p, xlo->getBeginPos());
+                qreal d1=Geometry::distance(p, xlo->getEndPos());
+                if (d0>d1)
+                    return link->getBeginLinkItem();
+                else
+                    return link->getEndLinkItem();
+            }
 	}
     }
 
@@ -797,12 +807,7 @@ AttributeTable* MapEditor::attributeTable()
 
 void MapEditor::testFunction1()
 {
-    BranchItem *sebi=model->getSelectedBranch();
-    if (sebi)
-    {
-	OrnamentedObj *oo=(OrnamentedObj*)(sebi->getLMO());
-	oo->setRotation (oo->getRotation()+10);
-    }
+  model->loadMap("/suse/uwedr/vym/code/test/default.vym");
 }
     
 void MapEditor::testFunction2()
@@ -1285,8 +1290,8 @@ void MapEditor::mousePressEvent(QMouseEvent* e)
 	    // if clicked near to begin of xlink
 	    if (ti->xlinkCount()>0 && ti->getType() != TreeItem::MapCenter && lmo->getBBox().width()>30)
 	    {
-		if ((lmo->getOrientation()!=LinkableMapObj::RightOfCenter && p.x() < lmo->getBBox().left()+20)  ||
-		    (lmo->getOrientation()!=LinkableMapObj::LeftOfCenter && p.x() > lmo->getBBox().right()-20) ) 
+		if ((lmo->getOrientation()!=LinkableMapObj::RightOfCenter && p.x() < lmo->getBBox().left()+10)  ||
+		    (lmo->getOrientation()!=LinkableMapObj::LeftOfCenter && p.x() > lmo->getBBox().right()-10) ) 
 		{
 		    //FIXME-4 similar code in mainwindow::updateActions
 		    QMenu menu;
@@ -1382,14 +1387,12 @@ void MapEditor::mousePressEvent(QMouseEvent* e)
 		{
 		    setState (EditingLink);
 		    int i=xlo->ctrlPointInClickBox(p);
-		    if (i>-1)
-		    {
-			xlo->setSelection (i);
-			movingObj_offset.setX( p.x() - xlo->x() );	
-			movingObj_offset.setY( p.y() - xlo->y() );	
-			movingObj_orgPos.setX (xlo->x() );
-			movingObj_orgPos.setY (xlo->y() );
-		    }
+		    if (i>=0) xlo->setSelection (i);
+                    movingObj_offset.setX( p.x() - xlo->x() );	
+                    movingObj_offset.setY( p.y() - xlo->y() );	
+                    movingObj_orgPos.setX (xlo->x() );
+                    movingObj_orgPos.setY (xlo->y() );
+
 		}
 	    }
 	}
@@ -1972,8 +1975,7 @@ void MapEditor::setState (EditorState s)
 	    case CopyingObject: s="CopyingObject";break;
 	    case DrawingLink: s="DrawingLink";break;
 	}
-	
-    qDebug()<<"MapEditor: State "<<s<< " of "<<model->getMapName();
+        qDebug()<<"MapEditor: State "<<s<< " of "<<model->getMapName();
     }
 }
 
