@@ -27,6 +27,7 @@ public:
     VymModel* getModel();
     QGraphicsScene * getScene();
 
+// Animation of scrollbars
 Q_PROPERTY(QPointF scrollBarPos READ getScrollBarPos WRITE setScrollBarPos)
 
 protected:
@@ -49,6 +50,7 @@ public:
     QPointF getScrollBarPos();
     void animateScrollBars();
 
+// Animation of zoom
 Q_PROPERTY(qreal zoomFactor READ getZoomFactor WRITE setZoomFactor)
 
 protected:
@@ -62,6 +64,43 @@ public:
     void setZoomFactor (const qreal &zf);
     qreal getZoomFactor();
 
+// Animation of rotation
+Q_PROPERTY(qreal angle READ getAngle WRITE setAngle)
+
+protected:
+    qreal angle;
+    qreal angleTarget;
+    QPropertyAnimation rotationAnimation;
+
+public:
+    void setAngleTarget (const qreal &a);
+    qreal getAngleTarget();
+    void setAngle (const qreal &a);
+    qreal getAngle();
+
+
+// Animation of viewCenter    
+Q_PROPERTY (QPointF viewCenter READ getViewCenter WRITE setViewCenter)
+
+protected:
+    QPointF viewCenter;
+    QPointF viewCenterTarget;
+
+public:
+    void setViewCenterTarget (
+	const QPointF &p, 
+	const qreal &zft, 
+	const qreal &at,
+	const int duration=2000,
+	const QEasingCurve &easingCurve=QEasingCurve::OutQuint);
+    void setViewCenterTarget ();    //! Convenience function, center on selected item
+    QPointF getViewCenterTarget();
+    void setViewCenter (const QPointF &p);
+    QPointF getViewCenter();
+    QPropertyAnimation viewCenterAnimation;
+
+    void updateMatrix();	    //! Sets transformation matrix with current rotation and zoom values
+
 public:
     void print();		    //!< Print the map
     QRectF getTotalBBox();	    //!< Bounding box of all items in map
@@ -73,13 +112,13 @@ public slots:
 public:
     TreeItem *findMapItem (QPointF p,TreeItem *exclude);    //! find item in map at position p. Ignore item exclude 
 
-    AttributeTable* attributeTable();	// FIXME-3
-    void testFunction1();		// just testing new stuff
-    void testFunction2();		// just testing new stuff
+    AttributeTable* attributeTable();	// FIXME-3 Not used, testing only
+    void testFunction1();		//! just testing new stuff
+    void testFunction2();		//! just testing new stuff
 
-    BranchItem* getBranchDirectAbove(BranchItem *bi);	//!  get branch direct above bi (in TreeView) 
+    BranchItem* getBranchDirectAbove(BranchItem *bi);	//! get branch direct above bi (in TreeView) 
     BranchItem* getBranchAbove(BranchItem *bi);		//! get branch above bi (in TreeView) 
-    BranchItem* getBranchDirectBelow(BranchItem *bi);	//!  bet branch direct below bi (in TreeView)
+    BranchItem* getBranchDirectBelow(BranchItem *bi);	//! bet branch direct below bi (in TreeView)
     BranchItem* getBranchBelow(BranchItem *bi);		//! bet branch below bi (in TreeView)
     BranchItem* getLeftBranch(BranchItem *bi);		//! bet branch left of bi (in TreeView)
     BranchItem* getRightBranch(BranchItem *bi);		//! bet branch right of bi (in TreeView)
@@ -94,7 +133,6 @@ public slots:
     void editHeading();
     void editHeadingFinished();
 private:
-    bool editingHeading;
     QLineEdit *lineEdit;
 
 protected:
@@ -127,10 +165,21 @@ private:
     QCursor PickColorCursor;	// cursor while picking color 
     QCursor CopyCursor;		// cursor while picking color 
     QCursor XLinkCursor;	// cursor while picking color 
-    bool pickingColor;
-    bool drawingLink;		// true while creating a link
-    bool copyingObj;		// true while modModeCopy
+    enum EditorState {
+	Neutral,
+	EditingHeading,
+	EditingLink,
+	MovingObject,
+	MovingView,
+	PickingColor,
+	CopyingObject,
+	DrawingLink
+    };
+    EditorState state; 
+    void setState (EditorState);
     bool objectMoved;		// true if object was not clicked, but moved with mouse
+
+    // Temporary used for linkx
     Link* tmpLink;
 
     MapObj* movingObj;		    // moving a MapObj
@@ -154,7 +203,7 @@ signals:
     void selectionChanged(const QItemSelection &, const QItemSelection &);
 
 private:    
-    QList <QGraphicsPolygonItem*> selPolyList;
+    QList <QGraphicsPathItem*> selPathList;
     QColor selectionColor;
 
 public slots:
