@@ -30,6 +30,8 @@ public slots:
     void saveAsClicked();
     void openClicked();
     void runClicked();
+    void loadMacroClicked();
+    void saveMacroClicked();
 
 signals:
     void runScript (QString);
