@@ -89,9 +89,8 @@ void SlideEditor::addSlide()
     vymModel->addSlide();
 }
 
-void SlideEditor::editSlide() 
+void SlideEditor::editSlide() // FIXME-4 not used yet
 {
-    SlideItem *si=slideModel->getSelectedItem();
 }
 
 void SlideEditor::deleteSlide() 
