@@ -91,6 +91,16 @@ QPointF XLinkObj::getAbsPos()
     }
 }
 
+QPointF XLinkObj::getBeginPos()
+{
+    return beginPos;
+}
+
+QPointF XLinkObj::getEndPos()
+{
+    return endPos;
+}
+
 void XLinkObj::move (QPointF p)
 {
     switch (curSelection)
@@ -246,6 +256,8 @@ void XLinkObj::updateXLink()
 	path->setZValue (dZ_XLINK); 
     else	
 	path->setZValue (dZ_XLINK);
+
+    setVisibility();
 }
 
 void XLinkObj::positionBBox()
@@ -387,6 +399,9 @@ bool XLinkObj::isInClickBox (const QPointF &p)
 	case FullShowControls:
 	    // If Cx selected, check both ctrl points 
 	    if (ctrlPointInClickBox(p) >-1) b=true;
+
+            // Enable selecting the path, when a ctrl point is already selected
+            if (!b && curSelection!=Unselected && clickPath.intersects (r)) b=true;
 	    break;
 	case Part:    
 	    // not selected, only partially visible
